@@ -23,13 +23,11 @@ import numpy as np
 from sklearn.cluster import AgglomerativeClustering
 from sklearn.tree import DecisionTreeClassifier
 from sklearn.utils.validation import check_is_fitted
-
-from probatus.utils import assure_numpy_array, TreePathFinder, ApproximationWarning
-
+from probatus.utils import assure_numpy_array, TreePathFinder, ApproximationWarning, BaseFitComputeClass
 import warnings
-from abc import ABC, abstractmethod
+from abc import abstractmethod
 
-class Bucketer(ABC):
+class Bucketer(BaseFitComputeClass):
 
     def __repr__(self):
         repr_ = f"{self.__class__.__name__}\n\tbincount: {self.bin_count}"
@@ -99,6 +97,8 @@ class SimpleBucketer(Bucketer):
 
     Example:
     ```python
+    from probatus.binning import SimpleBucketer
+
     x = [1, 2, 1]
     bins = 3
     myBucketer = SimpleBucketer(bin_count=bins)
@@ -135,6 +135,8 @@ class AgglomerativeBucketer(Bucketer):
 
     Usage:
     ```python
+    from probatus.binning import AgglomerativeBucketer
+
     x = [1, 2, 1]
     bins = 3
     myBucketer = AgglomerativeBucketer(bin_count=bins)
@@ -180,6 +182,8 @@ class QuantileBucketer(Bucketer):
 
     Usage:
     ```python
+    from probatus.binning import QuantileBucketer
+
     x = [1, 2, 1]
     bins = 3
     myBucketer = QuantileBucketer(bin_count=bins)
@@ -234,6 +238,8 @@ class TreeBucketer(Bucketer):
     
     Usage:
     ```python
+    from probatus.binning import TreeBucketer
+
     x = [1, 2, 2, 5 ,3]
     y = [0, 0 ,1 ,1 ,1]
     bins = 3
