@@ -1,15 +1,14 @@
-from probatus.utils import assure_pandas_df, shap_calc, calculate_shap_importance, \
-    NotFittedError, assure_pandas_series
+from probatus.utils import preprocess_data, shap_calc, calculate_shap_importance, BaseFitComputePlotClass, \
+    preprocess_labels, get_single_scorer
 import numpy as np
 import matplotlib.pyplot as plt
 import pandas as pd
-import warnings
 from sklearn.model_selection import RandomizedSearchCV, GridSearchCV, check_cv
 from sklearn.base import clone, is_classifier
-from sklearn.metrics import check_scoring
 from joblib import Parallel, delayed
+import warnings
 
-class ShapRFECV:
+class ShapRFECV(BaseFitComputePlotClass):
     """
     This class performs Backwards Recursive Feature Elimination, using SHAP feature importance. At each round, for a
         given feature set, starting from all available features, the following steps are applied:
@@ -40,30 +39,28 @@ class ShapRFECV:
 
     Example:
     ```python
+    import numpy as np
+    import pandas as pd
     from probatus.feature_elimination import ShapRFECV
     from sklearn.datasets import make_classification
     from sklearn.model_selection import train_test_split
-    import numpy as np
-    import pandas as pd
-    import lightgbm
+    from sklearn.ensemble import RandomForestClassifier
     from sklearn.model_selection import RandomizedSearchCV
 
-    feature_names = ['f1_categorical', 'f2_missing', 'f3_static', 'f4', 'f5', 'f6', 'f7', 'f8', 'f9', 'f10', 'f11', 'f12', 'f13', 'f14', 'f15', 'f16', 'f17', 'f18', 'f19', 'f20']
+    feature_names = ['f1', 'f2', 'f3', 'f4', 'f5', 'f6', 'f7', 'f8', 'f9', 'f10', 'f11', 'f12', 'f13', 'f14', 'f15', 'f16', 'f17', 'f18', 'f19', 'f20']
 
     # Prepare two samples
-    X, y = make_classification(n_samples=1000, class_sep=0.05, n_informative=6, n_features=20,
+    X, y = make_classification(n_samples=200, class_sep=0.05, n_informative=6, n_features=20,
                                random_state=0, n_redundant=10, n_clusters_per_class=1)
     X = pd.DataFrame(X, columns=feature_names)
-    X['f1_categorical'] = X['f1_categorical'].apply(lambda x: str(np.round(x*10)))
-    X['f2_missing'] = X['f2_missing'].apply(lambda x: x if np.random.rand()<0.8 else np.nan)
-    X['f3_static'] = 0
+
 
     # Prepare model and parameter search space
-    clf = lightgbm.LGBMClassifier(max_depth=5, class_weight='balanced')
+    clf = RandomForestClassifier(max_depth=5, class_weight='balanced')
 
     param_grid = {
         'n_estimators': [5, 7, 10],
-        'num_leaves': [3, 5, 7, 10],
+        'min_samples_leaf': [3, 5, 7, 10],
     }
     search = RandomizedSearchCV(clf, param_grid)
 
@@ -79,10 +76,11 @@ class ShapRFECV:
     # Get final feature set
     final_features_set = shap_elimination.get_reduced_features_set(num_features=3)
     ```
-
+    <img src="../img/shaprfecv.png" width="500" />
     """
 
-    def __init__(self, clf, step=1, min_features_to_select=1, cv=None, scoring=None, n_jobs=-1, random_state=None):
+    def __init__(self, clf, step=1, min_features_to_select=1, cv=None, scoring='roc_auc', n_jobs=-1, verbose=0,
+                 random_state=None):
         """
         This method initializes the class:
 
@@ -94,31 +92,43 @@ class ShapRFECV:
                 [GridSearchCV](https://scikit-learn.org/stable/modules/generated/sklearn.model_selection.GridSearchCV.html)
                 and [RandomizedSearchCV](https://scikit-learn.org/stable/modules/generated/sklearn.model_selection.RandomizedSearchCV.html).
 
-            step (Optional, int or float):
+            step (int or float, optional):
                 Number of lowest importance features removed each round. If it is an int, then each round such number of
                 features is discarded. If float, such percentage of remaining features (rounded down) is removed each
                 iteration. It is recommended to use float, since it is faster for a large number of features, and slows
                 down and becomes more precise towards less features. Note: the last round may remove fewer features in
                 order to reach min_features_to_select.
+                If columns_to_keep parameter is specified in the fit method, step is the number of features to remove after 
+                keeping those columns.
 
-            min_features_to_select (Optional, int):
+            min_features_to_select (int, optional):
                 Minimum number of features to be kept. This is a stopping criterion of the feature elimination. By
-                default the process stops when one feature is left.
+                default the process stops when one feature is left. If columns_to_keep is specified in the fit method,
+                it may overide this parameter to the maximum between length of columns_to_keep the two.
 
-            cv (Optional, int, cross-validation generator or an iterable):
+            cv (int, cross-validation generator or an iterable, optional):
                 Determines the cross-validation splitting strategy. Compatible with sklearn
                 [cv parameter](https://scikit-learn.org/stable/modules/generated/sklearn.feature_selection.RFECV.html).
                 If None, then cv of 5 is used.
 
-            scoring (Optional, string, callable or None):
-                A string (see sklearn [model scoring](https://scikit-learn.org/stable/modules/model_evaluation.html)) or
-                a scorer callable object, function with the signature `scorer(estimator, X, y)`.
+            scoring (string or probatus.utils.Scorer, optional):
+                Metric for which the model performance is calculated. It can be either a metric name  aligned with
+                predefined [classification scorers names in sklearn](https://scikit-learn.org/stable/modules/model_evaluation.html).
+                Another option is using probatus.utils.Scorer to define a custom metric.
 
-            n_jobs (Optional, int):
+            n_jobs (int, optional):
                 Number of cores to run in parallel while fitting across folds. None means 1 unless in a
                 `joblib.parallel_backend` context. -1 means using all processors.
 
-            random_state (Optional, int):
+            verbose (int, optional):
+                Controls verbosity of the output:
+
+                - 0 - nether prints nor warnings are shown
+                - 1 - 50 - only most important warnings
+                - 51 - 100 - shows other warnings and prints
+                - above 100 - presents all prints and all warnings (including SHAP warnings).
+
+            random_state (int, optional):
                 Random state set at each round of feature elimination. If it is None, the results will not be
                 reproducible and in random search at each iteration a different hyperparameters might be tested. For
                 reproducible results set it to integer.
@@ -141,68 +151,17 @@ class ShapRFECV:
             self.min_features_to_select=min_features_to_select
         else:
             raise (ValueError(f"The current value of min_features_to_select = {min_features_to_select} is not allowed. "
-                              f"It needs to be a positive integer."))
+                              f"It needs to be a greater than or equal to 0."))
 
         self.cv = cv
-        self.scorer = check_scoring(self.clf, scoring=scoring)
+        self.scorer = get_single_scorer(scoring)
         self.random_state = random_state
         self.n_jobs = n_jobs
         self.report_df = pd.DataFrame([])
-        self.fitted = False
+        self.verbose = verbose
 
 
-    def _check_if_fitted(self):
-        """
-        Checks if object has been fitted. If not, NotFittedError is raised.
-        """
-        if self.fitted is False:
-            raise(NotFittedError('The object has not been fitted. Please run fit() method first'))
-
-
-    @staticmethod
-    def _preprocess_data(X):
-        """
-        Does basic preprocessing of the data: Removal of static features, Warns which features have missing variables,
-        and transform object dtype features to category type, such that LightGBM handles them by default.
-
-        Args:
-            X (pd.DataFrame):
-                Provided dataset.
-
-        Returns:
-            (pd.DataFrame):
-                Preprocessed dataset.
-        """
-        # Make sure that X is a pd.DataFrame
-        X = assure_pandas_df(X)
-
-        # Remove static features, those that have only one value for all samples
-        static_features = [i for i in X.columns if len(X[i].unique()) == 1]
-        if len(static_features)>0:
-            warnings.warn(f'Removing static features {static_features}.')
-            X = X.drop(columns=static_features)
-
-        # Warn if missing
-        columns_with_missing = [column for column in X.columns if X[column].isnull().values.any()]
-        if len(columns_with_missing) > 0:
-            warnings.warn(f'The following variables contain missing values {columns_with_missing}. Make sure to impute'
-                          f'missing or apply a model that handles them automatically.')
-
-        # Transform Categorical variables into category dtype
-        indices_obj_dtype_features = [column[0] for column in enumerate(X.dtypes) if column[1] == 'O']
-        obj_dtype_features = list(X.columns[indices_obj_dtype_features])
-
-        # Set categorical features type to category
-        if len(obj_dtype_features) > 0:
-            warnings.warn(f'Changing dtype of {obj_dtype_features} from "object" to "category". Treating it as '
-                          f'categorical variable. Make sure that the model handles categorical variables, or encode '
-                          f'them first.')
-            for obj_dtype_feature in obj_dtype_features:
-                X[obj_dtype_feature] = X[obj_dtype_feature].astype('category')
-        return X
-
-
-    def _get_current_features_to_remove(self, shap_importance_df):
+    def _get_current_features_to_remove(self, shap_importance_df,columns_to_keep = None):
         """
         Implements the logic used to determine which features to remove. If step is a positive integer,
             at each round step lowest SHAP importance features are selected. If it is a float, such percentage
@@ -218,6 +177,15 @@ class ShapRFECV:
                 List of features to be removed at a given round.
         """
 
+        #Bounding the variable.
+        num_features_to_remove = 0
+
+        #If columns_to_keep is not None, exclude those columns and
+        #calculate features to remove.
+        if columns_to_keep is not None:
+            mask = shap_importance_df.index.isin(columns_to_keep)
+            shap_importance_df = shap_importance_df[~mask]
+
         # If the step is an int remove n features.
         if isinstance(self.step, int):
             num_features_to_remove = self._calculate_number_of_features_to_remove(
@@ -241,7 +209,6 @@ class ShapRFECV:
         if num_features_to_remove == 0:
             return []
         else:
-
             return shap_importance_df.iloc[-num_features_to_remove:].index.tolist()
 
 
@@ -321,7 +288,7 @@ class ShapRFECV:
 
 
     @staticmethod
-    def _get_feature_shap_values_per_fold(X, y, clf, train_index, val_index, scorer):
+    def _get_feature_shap_values_per_fold(X, y, clf, train_index, val_index, scorer, verbose=0):
         """
         This function calculates the shap values on validation set, and Train and Val score.
 
@@ -341,10 +308,18 @@ class ShapRFECV:
             val_index (np.array):
                 Positions of validation fold samples.
 
-            scorer (Optional, string, callable or None):
+            scorer (string, callable or None):
                 A string (see sklearn [model scoring](https://scikit-learn.org/stable/modules/model_evaluation.html)) or
                 a scorer callable object, function with the signature `scorer(estimator, X, y)`.
 
+            verbose (int, optional):
+                Controls verbosity of the output:
+
+                - 0 - neither prints nor warnings are shown
+                - 1 - 50 - only most important warnings regarding data properties are shown (excluding SHAP warnings)
+                - 51 - 100 - shows most important warnings, prints of the feature removal process
+                - above 100 - presents all prints and all warnings (including SHAP warnings).
+
         Returns:
             (np.array, float, float):
                 Tuple with the results: Shap Values on validation fold, train score, validation score.
@@ -360,11 +335,11 @@ class ShapRFECV:
         score_val = scorer(clf, X_val, y_val)
 
         # Compute SHAP values
-        shap_values = shap_calc(clf, X_val, suppress_warnings=True)
+        shap_values = shap_calc(clf, X_val, verbose=verbose)
         return shap_values, score_train, score_val
 
 
-    def fit(self, X, y):
+    def fit(self, X, y,columns_to_keep=None,column_names=None):
         """
         Fits the object with the provided data. The algorithm starts with the entire dataset, and then sequentially
              eliminates features. If [GridSearchCV](https://scikit-learn.org/stable/modules/generated/sklearn.model_selection.GridSearchCV.html)
@@ -378,24 +353,76 @@ class ShapRFECV:
 
             y (pd.Series):
                 Binary labels for X.
+
+            columns_to_keep (list of str, optional):
+                List of column names to keep. If given, these columns will not be eliminated by the feature elimination process.
+                However, these feature will used for the calculation of the SHAP values.
+
+            column_names (list of str, optional):
+                List of feature names of the provided samples. If provided it will be used to overwrite the existing
+                feature names. If not provided the existing feature names are used or default feature names are
+                generated.
+        Returns:
+            (ShapRFECV): Fitted object.
         """
         # Set seed for results reproducibility
         if self.random_state is not None:
             np.random.seed(self.random_state)
 
-        self.X = self._preprocess_data(X)
-        self.y = assure_pandas_series(y, index=self.X.index)
+        # If to columns_to_keep is not provided, then initialise it by an empty string.
+        # If provided check if all the elements in columns_to_keep are of type string.
+        if columns_to_keep is None:
+            len_columns_to_keep = 0
+        else :
+            if all(isinstance(x,str) for x in columns_to_keep):
+                len_columns_to_keep = len(columns_to_keep)
+            else :
+                raise(ValueError('The current values of columns_to_keep are not allowed.All the elements should be strings.'))
+        
+        # If the columns_to_keep parameter is provided, check if they match the column names in the X.
+        if column_names is not None :
+            if all(x in column_names for x in list(X.columns)):
+                pass
+            else :
+                raise(ValueError('The column names in parameter columns_to_keep and column_names are not macthing.'))
+
+        #Check that the total number of columns to select is less than total number of columns in the data.
+        #only when both parameters are provided.
+        if column_names is not None and columns_to_keep is not None :
+            if (self.min_features_to_select+len_columns_to_keep) > len(self.column_names):
+                raise ValueError('Minimum features to select is greater than number of features.'
+            'Lower the value for min_features_to_select or number of columns in columns_to_keep')
+
+
+        self.X , self.column_names = preprocess_data(X, X_name='X', column_names=column_names, verbose=self.verbose)
+        self.y = preprocess_labels(y, y_name='y', index=self.X.index, verbose=self.verbose)
         self.cv = check_cv(self.cv, self.y, classifier=is_classifier(self.clf))
 
-        remaining_features = current_features_set = self.X.columns.tolist()
+        remaining_features = current_features_set = self.column_names
         round_number = 0
 
-        while len(current_features_set) > self.min_features_to_select:
+        #Stop when stopping criteria is met.    
+        stopping_criteria = np.max([self.min_features_to_select,len_columns_to_keep])
+        
+        #Setting up the min_features_to_select parameter.
+        if columns_to_keep is None:
+            pass
+        else:
+            self.min_features_to_select = 0
+            #This ensures that, if columns_to_keep is provided ,the last features remaining are only the columns_to_keep.
+            if self.verbose > 50 :
+                warnings.warn(f'Minimum features to select : {stopping_criteria}')
+
+        while len(current_features_set) > stopping_criteria:
             round_number += 1
 
             # Get current dataset info
             current_features_set = remaining_features
-            current_X = self.X[current_features_set]
+            if columns_to_keep is None :
+                remaining_removeable_features = list(set(current_features_set))
+            else :
+                remaining_removeable_features = list(set(current_features_set) | set(columns_to_keep))
+            current_X = self.X[remaining_removeable_features]
 
             # Set seed for results reproducibility
             if self.random_state is not None:
@@ -410,18 +437,22 @@ class ShapRFECV:
 
             # Perform CV to estimate feature importance with SHAP
             results_per_fold = Parallel(n_jobs=self.n_jobs)(delayed(self._get_feature_shap_values_per_fold)(
-                X=current_X, y=self.y, clf=current_clf, train_index=train_index, val_index=val_index, scorer=self.scorer
+                X=current_X, y=self.y, clf=current_clf, train_index=train_index, val_index=val_index,
+                scorer=self.scorer.scorer, verbose=self.verbose
             ) for train_index, val_index in self.cv.split(current_X, self.y))
 
             shap_values = np.vstack([current_result[0] for current_result in results_per_fold])
             scores_train = [current_result[1] for current_result in results_per_fold]
             scores_val = [current_result[2] for current_result in results_per_fold]
 
-            shap_importance_df = calculate_shap_importance(shap_values, remaining_features)
+            #Calculate the shap features with remaining features and features to keep.
+           
+            shap_importance_df = calculate_shap_importance(shap_values, remaining_removeable_features)
 
             # Get features to remove
-            features_to_remove = self._get_current_features_to_remove(shap_importance_df)
+            features_to_remove = self._get_current_features_to_remove(shap_importance_df,columns_to_keep=columns_to_keep)
             remaining_features = list(set(current_features_set) - set(features_to_remove))
+            
 
             # Report results
             self._report_current_results(round_number=round_number, current_features_set=current_features_set,
@@ -430,15 +461,16 @@ class ShapRFECV:
                                          train_metric_std = np.round(np.std(scores_train), 3),
                                          val_metric_mean = np.round(np.mean(scores_val), 3),
                                          val_metric_std = np.round(np.std(scores_val), 3))
-
-            print(f'Round: {round_number}, Current number of features: {len(current_features_set)}, '
-                  f'Current performance: Train {self.report_df.loc[round_number]["train_metric_mean"]} '
-                  f'+/- {self.report_df.loc[round_number]["train_metric_std"]}, CV Validation '
-                  f'{self.report_df.loc[round_number]["val_metric_mean"]} '
-                  f'+/- {self.report_df.loc[round_number]["val_metric_std"]}. \n'
-                  f'Num of features left: {len(remaining_features)}. '
-                  f'Removed features at the end of the round: {features_to_remove}')
+            if self.verbose > 50:
+                print(f'Round: {round_number}, Current number of features: {len(current_features_set)}, '
+                      f'Current performance: Train {self.report_df.loc[round_number]["train_metric_mean"]} '
+                      f'+/- {self.report_df.loc[round_number]["train_metric_std"]}, CV Validation '
+                      f'{self.report_df.loc[round_number]["val_metric_mean"]} '
+                      f'+/- {self.report_df.loc[round_number]["val_metric_std"]}. \n'
+                      f'Features left: {remaining_features}. '
+                      f'Removed features at the end of the round: {features_to_remove}')
         self.fitted = True
+        return self
 
 
     def compute(self):
@@ -455,7 +487,7 @@ class ShapRFECV:
         return self.report_df
 
 
-    def fit_compute(self, X, y):
+    def fit_compute(self, X, y, columns_to_keep=None, column_names=None):
         """
         Fits the object with the provided data. The algorithm starts with the entire dataset, and then sequentially
              eliminates features. If [GridSearchCV](https://scikit-learn.org/stable/modules/generated/sklearn.model_selection.GridSearchCV.html)
@@ -471,12 +503,20 @@ class ShapRFECV:
             y (pd.Series):
                 Binary labels for X.
 
+            columns_to_keep (list of str, optional):
+                List of columns to keep. If given, these columns will not be eliminated.
+
+            column_names (list of str, optional):
+                List of feature names of the provided samples. If provided it will be used to overwrite the existing
+                feature names. If not provided the existing feature names are used or default feature names are
+                generated.
+
         Returns:
             (pd.DataFrame):
                 DataFrame containing results of feature elimination from each iteration.
         """
 
-        self.fit(X, y)
+        self.fit(X, y, columns_to_keep=columns_to_keep,column_names=column_names)
         return self.compute()
 
 
@@ -506,8 +546,9 @@ class ShapRFECV:
         Generates plot of the model performance for each iteration of feature elimination.
 
         Args:
-            show (Optional, bool):
-                If True, the plots are showed to the user, otherwise they are not shown.
+            show (bool, optional):
+                If True, the plots are showed to the user, otherwise they are not shown. Not showing plot can be useful,
+                when you want to edit the returned axis, before showing it.
 
             **figure_kwargs:
                 Keyword arguments that are passed to the plt.figure, at its initialization.
@@ -531,7 +572,7 @@ class ShapRFECV:
                          self.report_df['val_metric_mean'] + self.report_df['val_metric_std'], alpha=.3)
 
         plt.xlabel('Number of features')
-        plt.ylabel('Performance')
+        plt.ylabel(f'Performance {self.scorer.metric_name}')
         plt.title('Backwards Feature Elimination using SHAP & CV')
         plt.legend(loc="lower left")
         ax = plt.gca()
