@@ -32,14 +32,18 @@ from probatus.utils.arrayfuncs import check_numeric_dtypes
 class DistributionStatistics(object):
     """
     Wrapper that applies a statistical method to compare two distributions. Depending on a test, one can also apply
-     binning of the data.
+        binning of the data.
 
     Example:
     ```python
+    import numpy as np
+    import pandas as pd
+    from probatus.stat_tests import DistributionStatistics
+
     d1 = np.histogram(np.random.normal(size=1000), 10)[0]
     d2 = np.histogram(np.random.normal(size=1000), 10)[0]
     myTest = DistributionStatistics('KS', bin_count=10)
-    myTest.compute(d1, d2, verbose=True)
+    test_statistic, p_value = myTest.compute(d1, d2, verbose=True)
     ```
     """
 
@@ -82,25 +86,28 @@ class DistributionStatistics(object):
         Initializes the class.
 
         Args:
-            statistical_test (string): Statistical method to apply, statistical methods implemented:
+            statistical_test (string):
+                Statistical method to apply, statistical methods implemented:
 
-                - 'ES': Epps-Singleton
-                - 'KS': Kolmogorov-Smirnov statistic
-                - 'PSI': Population Stability Index
-                - 'SW': Shapiro-Wilk based difference statistic
-                - 'AD': Anderson-Darling TS
+                - `'ES'`: Epps-Singleton,
+                - `'KS'`: Kolmogorov-Smirnov statistic,
+                - `'PSI'`: Population Stability Index,
+                - `'SW'`: Shapiro-Wilk based difference statistic,
+                - `'AD'`: Anderson-Darling TS.
 
-            binning_strategy (Optional, string): Binning strategy to apply, binning strategies implemented:
+            binning_strategy (string, optional):
+                Binning strategy to apply, binning strategies implemented:
 
-                - 'simplebucketer': equally spaced bins
-                - 'agglomerativebucketer': binning by applying the Scikit-learn implementation of Agglomerative Clustering
-                - 'quantilebucketer': bins with equal number of elements
-                - 'default': applies a default binning for a given stats_test. For all tests appart from PSI, no binning (None)
-                 is used. For PSI by default quantilebucketer is used.
-                - None: no binning is applied. The test is computed based on original distribution.
+                - `'simplebucketer'`: equally spaced bins,
+                - `'agglomerativebucketer'`: binning by applying the Scikit-learn implementation of Agglomerative
+                    Clustering,
+                - `'quantilebucketer'`: bins with equal number of elements,
+                - `'default'`: applies a default binning for a given stats_test. For all tests appart from PSI, no
+                    binning (None) is used. For PSI by default quantilebucketer is used,
+                - `None`: no binning is applied. The test is computed based on original distribution.
 
-            bin_count (Optional, int): In case binning_strategy is not None, specify the number of bins to be used by the binning
-             strategy. By default 10 bins are used.
+            bin_count (int, optional): In case binning_strategy is not None, specify the number of bins to be used by
+                the binning strategy. By default 10 bins are used.
         """
         self.statistical_test = statistical_test.upper()
         self.binning_strategy = binning_strategy
@@ -140,6 +147,7 @@ class DistributionStatistics(object):
                 if binner is not None:
                     self.binner = binner(bin_count=self.bin_count)
 
+
     def __repr__(self):
         repr_ = "DistributionStatistics object\n\tstatistical_test: {}".format(
             self.statistical_test
@@ -158,23 +166,24 @@ class DistributionStatistics(object):
             repr_ += "\n\tp-value: {}".format(self.p_value)
         return repr_
 
-    def compute(self, d1, d2, verbose=False, **kwargs):
+
+    def compute(self, d1, d2, verbose=False):
         """
         Apply the statistical test and compute statistic value and p-value.
 
         Args:
-            d1: (np.array or pd.DataFrame): distribution 1.
+            d1: (np.array or pd.DataFrame):
+                distribution 1.
 
-            d2: (np.array or pd.DataFrame): distribution 2.
+            d2: (np.array or pd.DataFrame):
+                distribution 2.
 
-            verbose: (bool): Flag indicating whether prints should be shown.
-
-            **kwargs: Keyword arguments passed to the statistical test function:
-
-                - `verbose`:  helpful interpretation msgs printed to stdout (default False).
+            verbose: (bool, optional):
+                Flag indicating whether prints should be shown.
 
         Returns:
-            (Tuple of floats): statistic value and p_value. For PSI test the return is only statistic
+            (Tuple of floats):
+                statistic value and p_value. For PSI test the return is only statistic
         """
         check_numeric_dtypes(d1)
         check_numeric_dtypes(d2)
@@ -189,7 +198,7 @@ class DistributionStatistics(object):
 
         # Perform the statistical test
         res = self._statistical_test_function(
-            d1_preprocessed, d2_preprocessed, verbose=verbose, **kwargs
+            d1_preprocessed, d2_preprocessed, verbose=verbose
         )
         self.fitted = True
 
@@ -205,15 +214,21 @@ class DistributionStatistics(object):
 class AutoDist(object):
     """
     Class to automatically apply all implemented statistical distribution tests and binning strategies to (a
-    selection of) features in two dataframes.
+        selection of) features in two dataframes.
 
     Example:
     ```python
+    import numpy as np
+    import pandas as pd
+    from probatus.stat_tests import AutoDist
+
     df1 = pd.DataFrame(np.random.normal(size=(1000, 2)), columns=['feat_0', 'feat_1'])
     df2 = pd.DataFrame(np.random.normal(size=(1000, 2)), columns=['feat_0', 'feat_1'])
-    myAutoDist = AutoDist(statistical_tests='all', binning_strategies='all', bin_count=[10, 20])
-    res = myAutoDist.fit(df1, df2, columns=df1.columns)
+    myAutoDist = AutoDist(statistical_tests=["KS", "PSI"], binning_strategies='simplebucketer', bin_count=10)
+    myAutoDist.compute(df1, df2, column_names=df1.columns)
     ```
+
+    <img src="../img/autodist.png" width="700" />
     """
 
     def __init__(self, statistical_tests="all", binning_strategies="default", bin_count=10):
@@ -221,28 +236,29 @@ class AutoDist(object):
         Initializes the class.
 
         Args:
-            statistical_tests (Optional, str): Statistical tests to apply, either list of tests names, or 'all'. Statistical
-             methods implemented:
+            statistical_tests (str, optional): Statistical tests to apply, either list of tests names, or 'all'.
+                Statistical methods implemented:
 
-                - 'ES': Epps-Singleton,
-                - 'KS': Kolmogorov-Smirnov statistic,
-                - 'PSI': Population Stability Index,
-                - 'AD': Anderson-Darling TS.
+                - `'ES'`: Epps-Singleton,
+                - `'KS'`: Kolmogorov-Smirnov statistic,
+                - `'PSI'`: Population Stability Index,
+                - `'AD'`: Anderson-Darling TS.
 
-            binning_strategies (Optional, str): Binning strategies to apply for each test, either list of tests names, 'all'
-             or 'default'. Binning strategies that can be chosen:
+            binning_strategies (str, optional): Binning strategies to apply for each test, either list of tests names,
+                'all' or 'default'. Binning strategies that can be chosen:
 
-                - 'SimpleBucketer': equally spaced bins,
-                - 'AgglomerativeBucketer': binning by applying the Scikit-learn implementation of Agglomerative Clustering,
-                - 'QuantileBucketer': bins with equal number of elements,
-                - None: no binning is applied. Note that not all statistical tests will be performed since
-                  some () require binning strategies.
-                - 'default': applies a default binning for a given stats_test. For all tests appart from PSI, no binning (None)
-                is used. For PSI by default quantilebucketer is used.
-                - 'all': each binning strategy is used for each statistical test
+                - `'SimpleBucketer'`: equally spaced bins,
+                - `'AgglomerativeBucketer'`: binning by applying the Scikit-learn implementation of Agglomerative
+                    Clustering,
+                - `'QuantileBucketer'`: bins with equal number of elements,
+                - `None`: no binning is applied. Note that not all statistical tests will be performed since some of
+                    them require binning strategies.
+                - `'default'`: applies a default binning for a given stats_test. For all tests appart from PSI, no
+                    binning (None) is used. For PSI by default quantilebucketer is used.
+                - `'all'`: each binning strategy is used for each statistical test
 
-            bin_count (integer, None or list of integers): bin_count value(s) to be used, note that None can only be used when
-             no bucketing strategy is applied.
+            bin_count (integer, None or list of integers, optional):
+                bin_count value(s) to be used, note that None can only be used when no bucketing strategy is applied.
         """
         self.fitted = False
 
@@ -283,32 +299,30 @@ class AutoDist(object):
         repr_ += "\n\tbin_count: {}".format(self.bin_count)
         return repr_
 
-    def compute(
-        self,
-        df1,
-        df2,
-        column_names=None,
-        return_failed_tests=True,
-        suppress_warnings=False,
-    ):
+    def compute(self, df1, df2, column_names=None, return_failed_tests=True, suppress_warnings=False):
         """
-        Fit the AutoDist object to data; i.e. apply the statistical tests and binning strategies
+        Fit the AutoDist object to data; i.e. apply the statistical tests and binning strategies.
 
         Args:
 
-            df1 (pd.DataFrame): dataframe 1 for distribution comparison with dataframe 2.
+            df1 (pd.DataFrame):
+                dataframe 1 for distribution comparison with dataframe 2.
 
-            df2 (pd.DataFrame): dataframe 2 for distribution comparison with dataframe 1.
+            df2 (pd.DataFrame):
+                dataframe 2 for distribution comparison with dataframe 1.
 
-            column_names (list of str): list of columns in df1 and df2 that should be compared. If None, 
-             all column names will be compared
+            column_names (list of str, optional):
+                list of columns in df1 and df2 that should be compared. If None, all column names will be compared
 
-            return_failed_tests (bool): remove tests in result that did not succeed.
+            return_failed_tests (bool, optional):
+                remove tests in result that did not succeed.
 
-            suppress_warnings (bool): whether to suppress warnings during the fit process.
+            suppress_warnings (bool, optional):
+                whether to suppress warnings during the fit process.
 
         Returns:
-            (pd.DataFrame): dataframe with results of the performed statistical tests and binning strategies.
+            (pd.DataFrame):
+                dataframe with results of the performed statistical tests and binning strategies.
 
         """
         if column_names is None:
